@@ -1,3 +1,5 @@
+import os
+import atexit
 import logging
 from   logging import DEBUG, INFO, WARN, ERROR
 
@@ -13,6 +15,7 @@ def setup_logging(logfname=None, level=None):
         level  = logging.INFO
     format = '[%(levelname)s %(filename)s ln=%(lineno)s] %(message)s'
     if logfname is not None:
+        os.makedirs(os.path.dirname(logfname), exist_ok=True)
         logging.basicConfig(level=level, filename=logfname, filemode='w', format=format)
     else:
         logging.basicConfig(level=level, format=format)
@@ -25,6 +28,20 @@ def silence_penman():
     #logging.getLogger('penman._lexer').setLevel(logging.ERROR)
     logging.getLogger('pe').setLevel(logging.ERROR)     # pre v1.1, penman._parse.py
 
+
 # Silense the request library
 def silence_requests():
     logging.getLogger('urllib3.connectionpool').setLevel(logging.ERROR)
+
+
+# smatch/amr logs to stderr.  Redirect to a file
+def setup_smatch_log(fpath):
+    import amr
+    import smatch
+    os.makedirs(os.path.dirname(fpath), exist_ok=True)
+    smatch_log_f = open(fpath, 'w', buffering=1)    # line buffering
+    atexit.register(smatch_log_f.close)
+    amr.ERROR_LOG    = smatch_log_f
+    amr.DEBUG_LOG    = smatch_log_f
+    smatch.ERROR_LOG = smatch_log_f
+    smatch.DEBUG_LOG = smatch_log_f
